Module parser

Module parser 

LCM type definition file parser

Structs

ArrayType
Const
Field
Schema
Struct
StructType

Enums

ArrayDimension
ConstValue
PrimitiveType
StructMember
Type

Functions

block_comment
Match a C-style comment
const_decl
Parse a const declaration, inside a struct. (doesn’t handle the semicolon or preceding whitespace)
const_value
Parse a const value of the given type.
field_decl
Parse a field declaration, inside a struct, including array dimensions. (doesn’t handle the semicolon or preceding whitespace)
field_type
Parse the type part of a field decl.
ident
Names that can be used for structs, packages, or fields
line_comment
Match a C++-style comment
package_decl
Parse a package line, not including the semicolon.
primitive_type
Parse an LCM primitive type
schema
Parse an entire schema file
spaced_comma
Match a comma, optionally surrounded by spaces
struct_decl
Parse a whole struct declaration.
struct_member
ws
Whitespace parser. This includes regular spaces, newlines, and comments.